pub struct ConfigIssue {
pub key: String,
pub message: String,
pub severity: i32,
}Expand description
Something wrong with the config that reading it is enough to establish.
Fields
key: StringDotted path to the offending key, spelled as in ConfigProbe.
message: Stringseverity: i32Implementations
Sourceimpl ConfigIssue
impl ConfigIssue