pub trait EngineToggle {
// Required methods
fn enabled(&self) -> bool;
fn set_enabled(&mut self, v: bool);
}Expand description
Trait for engine configs that can be toggled with a bool shorthand.
pub trait EngineToggle {
// Required methods
fn enabled(&self) -> bool;
fn set_enabled(&mut self, v: bool);
}Trait for engine configs that can be toggled with a bool shorthand.