pub struct WasmEngine { /* private fields */ }Expand description
A WASM checker plugin loaded via Extism.
The plugin must export a check function that accepts a JSON string
{"text": "...", "language_id": "..."} and returns a JSON array of
diagnostics matching the ExternalDiagnostic schema.
Implementations
Sourceimpl WasmEngine
impl WasmEngine
Sourcepub fn new(
name: String,
wasm_path: PathBuf,
extensions: Vec<String>,
languages: Vec<String>,
) -> Result<Self>
pub fn new( name: String, wasm_path: PathBuf, extensions: Vec<String>, languages: Vec<String>, ) -> Result<Self>
Create a new WASM engine from a .wasm file path.
Sourcepub fn handles_extension(&self, extension: Option<&str>) -> bool
pub fn handles_extension(&self, extension: Option<&str>) -> bool
Whether this plugin parses the markup of the document being checked.
Sourcepub fn from_bytes(name: String, wasm_bytes: &[u8]) -> Result<Self>
pub fn from_bytes(name: String, wasm_bytes: &[u8]) -> Result<Self>
Create a new WASM engine from raw bytes (useful for testing).