pub struct IgnoreRange {
pub byte_range: Range<usize>,
pub rule_ids: Vec<String>,
}Expand description
A resolved byte range that should be ignored during checking.
Fields
byte_range: Range<usize>Byte range to ignore.
rule_ids: Vec<String>If set, only ignore diagnostics matching these rule IDs.