pub enum AffixStep {
Prefix(&'static str),
Suffix(&'static str),
}Expand description
One affix removed on the way to a known root.
Variants
Prefix(&'static str)
A productive prefix, as written in the prefix list.
Suffix(&'static str)
A derivational suffix, as written in [SUFFIX_RULES].