IgnoreDirective

Struct IgnoreDirective 

pub struct IgnoreDirective {
    pub line_start: usize,
    pub line_end: usize,
    pub kind: DirectiveKind,
    pub rule_ids: Vec<String>,
    pub options: Option<BeginOptions>,
}
A parsed inline ignore directive.

Fields

line_start: usize

The byte offset of the line containing this directive.

line_end: usize

The byte offset of the end of the line containing this directive.

kind: DirectiveKind

What kind of directive this is.

rule_ids: Vec<String>

If set, only suppress the specified rule IDs (unified or native). If empty, suppress all rules. Used by Disable/DisableNextLine.

options: Option<BeginOptions>

Options for Begin directives; None for all other kinds.