pub struct ProseRange {
pub start_byte: usize,
pub end_byte: usize,
pub exclusions: Vec<(usize, usize)>,
}Fields
start_byte: usizeend_byte: usizeexclusions: Vec<(usize, usize)>Byte ranges (document-level) within this prose range that should be excluded from grammar checking (e.g. display math). These regions are replaced with spaces when extracting text, preserving byte offsets.
Implementations
Sourceimpl ProseRange
impl ProseRange
Sourcepub fn extract_text<'a>(&self, text: &'a str) -> Cow<'a, str>
pub fn extract_text<'a>(&self, text: &'a str) -> Cow<'a, str>
Extract the prose text from the full document, replacing any excluded regions with spaces so that byte offsets remain stable.
Sourcepub fn overlaps_exclusion(&self, local_start: u32, local_end: u32) -> bool
pub fn overlaps_exclusion(&self, local_start: u32, local_end: u32) -> bool
Check whether a local byte range (relative to this prose range) overlaps with any exclusion zone.